@@ -1,9 +1,10 @@
 import sys
+import types
 
 from je_api_testka.requests_wrapper.request_method import test_api_method
-from je_api_testka.utils.exception.exception_tag import executor_data_error
-from je_api_testka.utils.exception.exception_tag import executor_list_error
-from je_api_testka.utils.exception.exceptions import APITesterExecuteException
+from je_api_testka.utils.exception.exception_tag import executor_data_error, executor_list_error
+from je_api_testka.utils.exception.exception_tag import add_command_exception_tag
+from je_api_testka.utils.exception.exceptions import APITesterExecuteException, APIAddCommandException
 from je_api_testka.utils.html_report.html_report_generate import generate_html
 from je_api_testka.utils.json.json_file.json_file import read_action_json
 
@@ -38,8 +39,7 @@ class Executor(object):
         for loop and use execute_event function to execute
         :return: recode string, response as list
         """
-        execute_record_string = ""
-        event_response_list = []
+        execute_record_dict = dict()
         try:
             if len(action_list) > 0 or type(action_list) is not list:
                 pass
@@ -50,12 +50,11 @@ class Executor(object):
         for action in action_list:
             try:
                 event_response = self.execute_event(action)
-                print("execute: ", str(action))
-                execute_record_string = "".join(execute_record_string)
-                event_response_list.append(event_response)
+                execute_record = "execute: " + str(action)
+                execute_record_dict.update({execute_record: event_response})
             except Exception as error:
                 print(repr(error), file=sys.stderr)
-        return execute_record_string, event_response_list
+        return execute_record_dict
 
     def execute_files(self, execute_files_list: list):
         """
@@ -71,6 +70,14 @@ class Executor(object):
 executor = Executor()
 
 
+def add_command_to_executor(command_dict: dict):
+    for command_name, command in command_dict.items():
+        if isinstance(command, (types.MethodType, types.FunctionType)):
+            executor.event_dict.update({command_name: command})
+        else:
+            raise APIAddCommandException(add_command_exception_tag)
+
+
 def execute_action(action_list: list):
     return executor.execute_action(action_list)
 
