@@ -1,12 +1,10 @@
 import json
-import os.path
 from pathlib import Path
 from threading import Lock
 
+from je_api_testka.utils.exception.exception_tag import cant_find_json_error
+from je_api_testka.utils.exception.exception_tag import cant_save_json_error
 from je_api_testka.utils.exception.exceptions import APITesterJsonException
-from je_api_testka.utils.exception.exceptions_tag import api_test_cant_find_json_error
-from je_api_testka.utils.exception.exceptions_tag import api_test_cant_save_json_error
-
 
 lock = Lock()
 
@@ -23,7 +21,7 @@ def read_action_json(json_file_path: str):
             with open(json_file_path) as read_file:
                 return json.load(read_file)
     except APITesterJsonException:
-        raise APITesterJsonException(api_test_cant_find_json_error)
+        raise APITesterJsonException(cant_find_json_error)
     finally:
         lock.release()
 
@@ -39,7 +37,6 @@ def write_action_json(json_save_path: str, action_json: list):
         with open(json_save_path, "w+") as file_to_write:
             file_to_write.write(json.dumps(action_json))
     except APITesterJsonException:
-        raise APITesterJsonException(api_test_cant_save_json_error)
+        raise APITesterJsonException(cant_save_json_error)
     finally:
         lock.release()
-
